# Table of Contents

- [faqs](<./faqs.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [FAQs](<./FAQs.md>)
  - [What Is a Fact Sheet?](<./FAQs/What-Is-a-Fact-Sheet.md>)
  - [What Is a Workspace?](<./FAQs/What-Is-a-Workspace.md>)
  - [Which Browsers Are Supported?](<./FAQs/Which-Browsers-Are-Supported.md>)
  - [How Can I See the Current Version?](<./FAQs/How-Can-I-See-the-Current-Version.md>)
  - [What Personal Data Is Stored in SAP LeanIX?](<./FAQs/What-Personal-Data-Is-Stored-in-SAP-LeanIX.md>)
  - [How Can I Retrieve the Changelog for Any Changes Made to a User Within SAP LeanIX?](<./FAQs/How-Can-I-Retrieve-the-Changelog-for-Any-Changes-Made-to-a-User-Within-SAP-LeanIX.md>)
  - [Where Can I View and Access My Personal Data?](<./FAQs/Where-Can-I-View-and-Access-My-Personal-Data.md>)
  - [How Can I Export My Data from SAP LeanIX?](<./FAQs/How-Can-I-Export-My-Data-from-SAP-LeanIX.md>)
  - [Implemented Security Measures in SAP LeanIX](<./FAQs/Implemented-Security-Measures-in-SAP-LeanIX.md>)
